@@ -1,7 +1,7 @@
 package EBook::Tools::Unpack;
 use warnings; use strict; use utf8;
 use English qw( -no_match_vars );
-use version 0.74; our $VERSION = qv("0.4.5");
+use version 0.74; our $VERSION = qv("0.4.6");
 
 # Perl Critic overrides:
 ## no critic (Package variable)
@@ -218,7 +218,7 @@ my @fields = (
     'tidy',
     'nosave',
     );
-    
+
 require fields;
 fields->import(@fields);
 
@@ -412,7 +412,7 @@ Croaks if detection fails.
 
 In scalar context, returns C<< $self->{format} >>.  In list context,
 returns the two element list C<< ($self->{format},$self->{formatinfo}) >>
- 
+
 This is automatically called by L</new()> if the C<format> argument is
 not specified.
 
@@ -471,7 +471,7 @@ sub detect_format :method
         debug(1,"DEBUG: Autodetected book format '",$$self{format},
               "', version ",$$self{formatinfo});
     }
-    
+
     # Check for ePub
     $ident = substr($headerdata,30,28);
     $info = substr($headerdata,0,2);
@@ -552,7 +552,7 @@ sub detect_from_mobi_exth :method
         {
             $data = $$exth{data};
         }
-        
+
         if($exth_repeats{$$exth{type}})
         {
             debug(2,"DEBUG: Repeating EXTH ",$type," = '",$data,"'");
@@ -608,7 +608,7 @@ remains to the manifest of the OPF.
 =item * C<mediatype> (optional)
 
 The media type (mime type) of the document specified via C<textfile>.
-If C<textfile> is not specified, this argument is ignored.  If C<textfile> is specified, but 
+If C<textfile> is not specified, this argument is ignored.  If C<textfile> is specified, but
 
 =back
 
@@ -658,19 +658,19 @@ sub gen_opf :method   ## no critic (Always unpack @_ first)
     }
     $ebook->fix_metastructure_oeb12();
     $ebook->add_document($textfile,'text-main',$mediatype) if($textfile);
-    
+
     # Set author, title, and opffile from manual overrides
     $ebook->set_primary_author(text => $$self{author}) if($$self{author});
     $ebook->set_title(text => $$self{title}) if($$self{title});
     $ebook->set_opffile($$self{opffile}) if($$self{opffile});
-    
+
     # If we still don't have author or title, set it from the best
     # extraction we have
     $ebook->set_primary_author(text => $$self{detected}{author})
         if(!$$self{author} && $$self{detected}{author});
     $ebook->set_title(text => $$self{detected}{title})
         if(!$$self{title} && $$self{detected}{title});
-    
+
     # Set the language codes
     $ebook->set_language(text => $$self{detected}{language})
         if($$self{detected}{language});
@@ -769,14 +769,14 @@ sub gen_opf :method   ## no critic (Always unpack @_ first)
     $ebook->set_retailprice(text => $$self{detected}{retailprice},
                             currency => $$self{detected}{currency})
         if($$self{detected}{retailprice});
-    
+
     # Automatically clean up any mess
     $ebook->fix_misc;
     $ebook->fix_oeb12;
     $ebook->fix_mobi;
     unlink($opffile);
     $ebook->save;
-    return 1;    
+    return 1;
 }
 
 
@@ -855,7 +855,7 @@ sub unpack_ereader :method
         {
             $textname = $pdb->write_html();
             $self->gen_opf(textfile => $textname,
-                           mediatype => 'text/html');
+                           mediatype => 'application/xhtml+xml');
         }
         else
         {
@@ -883,7 +883,7 @@ sub unpack_imp
 
     my $imp = EBook::Tools::IMP->new();
     $imp->load($self->{file});
-    
+
     $self->{detected}->{author} = $imp->author;
     $self->{detected}->{title} = $imp->title;
 
@@ -891,7 +891,7 @@ sub unpack_imp
     {
         $imp->write_resdir();
     }
-    
+
     $imp->write_text(dir => $self->{dir});
     $imp->write_images(dir => $self->{dir});
 
@@ -924,7 +924,7 @@ sub unpack_mobi :method
     # Used for file output
     my $htmlname = $self->filebase . ".html";
 
-    my $reccount = 0; # The Record ID cannot be reliably used to identify 
+    my $reccount = 0; # The Record ID cannot be reliably used to identify
                       # the first record.  This increments as each
                       # record is examined
 
@@ -946,7 +946,7 @@ sub unpack_mobi :method
     = $mobi->{header}{mobi}{dolanguage};
 
     $self->detect_from_mobi_exth();
-    
+
     if($$self{raw} && !$$self{nosave})
     {
         $mobi->write_unknown_records();
@@ -1048,12 +1048,12 @@ sub unpack_palmdoc :method
             print {*$fh} $pdb->text;
             close($fh)
                 or croak("Failed to close '",$outfile,"'!");
-        }   
+        }
 
         open($fh,">:raw",$bookmarkfile)
             or croak("Failed to open '",$bookmarkfile,"' for writing!");
         %bookmarks = $pdb->bookmarks;
-        if(%bookmarks) 
+        if(%bookmarks)
         {
             foreach my $offset (sort {$a <=> $b} keys %bookmarks)
             {
